---
layout: page
title: proxmox_virtual_environment_metrics_server
parent: Resources
subcategory: Virtual Environment
description: |-
  Manages PVE metrics server.
---

# Resource: proxmox_virtual_environment_metrics_server

Manages PVE metrics server.

## Example Usage

```terraform
resource "proxmox_virtual_environment_metrics_server" "influxdb_server" {
  name   = "example_influxdb_server"
  server = "192.168.3.2"
  port   = 8089
  type   = "influxdb"
}

resource "proxmox_virtual_environment_metrics_server" "graphite_server" {
  name   = "example_graphite_server"
  server = "192.168.4.2"
  port   = 2003
  type   = "graphite"
}
```

<!-- schema generated by tfplugindocs -->
## Schema

### Required

- `name` (String) Unique name that will be ID of this metric server in PVE.
- `port` (Number) Server network port.
- `server` (String) Server dns name or IP address.
- `type` (String) Plugin type. Choice is between `graphite` | `influxdb`.

### Optional

- `disable` (Boolean) Set this to `true` to disable this metric server.
- `graphite_path` (String) Root graphite path (ex: `proxmox.mycluster.mykey`).
- `graphite_proto` (String) Protocol to send graphite data. Choice is between `udp` | `tcp`. If not set, PVE default is `udp`.
- `influx_api_path_prefix` (String) An API path prefix inserted between `<host>:<port>/` and `/api2/`. Can be useful if the InfluxDB service runs behind a reverse proxy.
- `influx_bucket` (String) The InfluxDB bucket/db. Only necessary when using the http v2 api.
- `influx_db_proto` (String) Protocol for InfluxDB. Choice is between `udp` | `http` | `https`. If not set, PVE default is `udp`.
- `influx_max_body_size` (Number) InfluxDB max-body-size in bytes. Requests are batched up to this size. If not set, PVE default is `25000000`.
- `influx_organization` (String) The InfluxDB organization. Only necessary when using the http v2 api. Has no meaning when using v2 compatibility api.
- `influx_token` (String, Sensitive) The InfluxDB access token. Only necessary when using the http v2 api. If the v2 compatibility api is used, use `user:password` instead.
- `influx_verify` (Boolean) Set to `false` to disable certificate verification for https endpoints.
- `mtu` (Number) MTU (maximum transmission unit) for metrics transmission over UDP. If not set, PVE default is `1500` (allowed `512` - `65536`).
- `timeout` (Number) TCP socket timeout in seconds. If not set, PVE default is `1`.

### Read-Only

- `id` (String) The unique identifier of this resource.

## Import

Import is supported using the following syntax:

```shell
#!/usr/bin/env sh
terraform import proxmox_virtual_environment_metrics_server.example example
```
